@@ -1,36 +1,47 @@
-import datetime
+import sys
 import json
 import logging
-import logging.handlers
+import datetime
 import traceback
-import sys
+import logging.handlers
 
 from .sender import LogzioSender
+from .exceptions import LogzioException
 
 
 class LogzioHandler(logging.Handler):
 
-    def __init__(self, token, logzio_type="python", logs_drain_timeout=3,
-                 url="https://listener.logz.io:8071", debug=False):
+    def __init__(self,
+                 token,
+                 logzio_type="python",
+                 logs_drain_timeout=3,
+                 url="https://listener.logz.io:8071",
+                 debug=False):
 
-        if token is "":
-            raise Exception("Logz.io Token must be provided")
+        if not token:
+            raise LogzioException('Logz.io Token must be provided')
 
         self.logzio_type = logzio_type
 
-        self.logzio_sender = LogzioSender(token=token, url=url, logs_drain_timeout=logs_drain_timeout, debug=debug)
+        self.logzio_sender = LogzioSender(
+            token=token,
+            url=url,
+            logs_drain_timeout=logs_drain_timeout,
+            debug=debug)
         logging.Handler.__init__(self)
 
     def extra_fields(self, message):
 
         not_allowed_keys = (
-            'args', 'asctime', 'created', 'exc_info', 'stack_info', 'exc_text', 'filename',
-            'funcName', 'levelname', 'levelno', 'lineno', 'module',
+            'args', 'asctime', 'created', 'exc_info', 'stack_info', 'exc_text',
+            'filename', 'funcName', 'levelname', 'levelno', 'lineno', 'module',
             'msecs', 'msecs', 'message', 'msg', 'name', 'pathname', 'process',
             'processName', 'relativeCreated', 'thread', 'threadName')
 
         if sys.version_info < (3, 0):
-            var_type = (basestring, bool, dict, float, int, long, list, type(None))
+            # long and basestring don't exist in py3 so, NOQA
+            var_type = (basestring, bool, dict, float,  # NOQA
+                        int, long, list, type(None))  # NOQA
         else:
             var_type = (str, bool, dict, float, int, list, type(None))
 
@@ -60,29 +71,29 @@ class LogzioHandler(logging.Handler):
 
     def format_message(self, message):
         now = datetime.datetime.utcnow()
-        timestamp = now.strftime("%Y-%m-%dT%H:%M:%S") + ".%03d" % (now.microsecond / 1000) + "Z"
+        timestamp = now.strftime('%Y-%m-%dT%H:%M:%S') + \
+            '.%03d' % (now.microsecond / 1000) + 'Z'
 
         return_json = {
-            "logger": message.name,
-            "line_number": message.lineno,
-            "path_name": message.pathname,
-            "log_level": message.levelname,
-            "type": self.logzio_type,
-            "message": message.getMessage(),
-            "@timestamp": timestamp
+            'logger': message.name,
+            'line_number': message.lineno,
+            'path_name': message.pathname,
+            'log_level': message.levelname,
+            'type': self.logzio_type,
+            'message': message.getMessage(),
+            '@timestamp': timestamp
         }
 
         if message.exc_info:
-            return_json["exception"] = self.format_exception(message.exc_info)
+            return_json['exception'] = self.format_exception(message.exc_info)
         else:
             formatted_message = self.format(message)
-
             return_json.update(self.extra_fields(message))
 
             if isinstance(formatted_message, dict):
                 return_json.update(formatted_message)
             else:
-                return_json["message"] = formatted_message
+                return_json['message'] = formatted_message
 
         return return_json
 
